@@ -12,7 +12,6 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with openreviewio-py.  If not, see <https://www.gnu.org/licenses/>
-
 from pathlib import Path
 import toml
 from typing import Union
@@ -30,6 +29,17 @@ class TextComment:
         self.body = body
 
 
+class TextAnnotation(TextComment):
+    frame: int
+    duration: int
+
+    def __init__(self, body: str, frame: int, duration: int):
+        super().__init__(body)
+
+        self.frame = frame
+        self.duration = duration
+
+
 class Image:
 
     __mime__ = {"jpeg", "jpg", "png"}
