@@ -32,7 +32,7 @@ from inspect import getmembers, isclass
 
 class MediaReview:
 
-    media: Path
+    _media: Path
     _status_history: List[Status] = []  # Read only
 
     def __init__(
@@ -49,7 +49,7 @@ class MediaReview:
         :param notes: Review's notes ordered by creation date. TODO Read only ?
         :param metadata: Review's metadata.
         """
-        self.media = Path(media)
+        self.media = media
 
         self.status = status or Status("waiting review", "default")
 
@@ -59,6 +59,15 @@ class MediaReview:
 
         self.metadata = metadata or {}
 
+    # Media getter and setter
+    @property
+    def media(self):
+        return self._media
+
+    @media.setter
+    def media(self, value):
+        self._media = Path(value)
+
     def add_note(self, note: Union[Note, List[Note]] = None):
         """Append a note (or all notes if a list is provided) it to the review's notes list.
 
@@ -224,24 +233,29 @@ class MediaReview:
                             # Keep files to copy
                             new_attachment_path = review_folder.joinpath(relative_path)
                             files_to_copy.append(
-                                (Path(image_path), new_attachment_path,)
+                                (
+                                    Path(image_path),
+                                    new_attachment_path,
+                                )
                             )
                             # Update attribute of written note
                             setattr(c, attribute, new_attachment_path)
 
                         else:
                             params[attribute] = str(value)
-                
+
                 # Test if body characters are accepted, else clean it
                 try:
                     content = ET.Element(c.__class__.__name__, params)
                 except ValueError:
                     import string
 
-                    string_to_clean = params.get('body')
+                    string_to_clean = params.get("body")
                     printable = set(string.printable)
-                    params['body'] = string_to_clean.encode('utf8', errors='replace').decode('utf8')
-                
+                    params["body"] = "".join([s for s in string_to_clean if s in string.printable])
+
+                    content = ET.Element(c.__class__.__name__, params)
+
                 contents.append(content)
 
             # Set note metadata
@@ -272,6 +286,8 @@ class MediaReview:
             if not target.is_file():
                 shutil.copy2(source, target)
 
+        return review_folder
+
     def compare(self, review: MediaReview) -> MediaReview:
         """Compare the current review with the given one.
         TODO: Not implemented yet!
@@ -288,6 +304,5 @@ class MediaReview:
         return self._status_history
 
     def set_status_history(self, statuses_list):
-        """Set the statuses history of the review.
-        """
+        """Set the statuses history of the review."""
         self._status_history = statuses_list
